==> libgda-0.11.0.tar.bz2: libgda-0.11.0/libsql/parser.h <==
/* A Bison parser, made from parser.y, by GNU bison 1.75.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

#ifndef BISON_PARSER_H
# define BISON_PARSER_H

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     L_SELECT = 258,
     L_FROM = 259,
     L_WHERE = 260,
     L_AS = 261,
     L_JOIN = 262,
     L_ON = 263,
     L_ORDER = 264,
     L_BY = 265,
     L_DISTINCT = 266,
     L_BETWEEN = 267,
     L_IN = 268,
     L_GROUP = 269,
     L_INSERT = 270,
     L_INTO = 271,
     L_VALUES = 272,
     L_UPDATE = 273,
     L_SET = 274,
     L_DOT = 275,
     L_STAR = 276,
     L_COMMA = 277,
     L_NULL = 278,
     L_LBRACKET = 279,
     L_RBRACKET = 280,
     L_IDENT = 281,
     L_EQ = 282,
     L_IS = 283,
     L_LIKE = 284,
     L_NOT = 285,
     L_AND = 286,
     L_OR = 287,
     L_MINUS = 288,
     L_PLUS = 289,
     L_TIMES = 290,
     L_DIV = 291,
     L_STRING = 292
   };
#endif
#define L_SELECT 258
#define L_FROM 259
#define L_WHERE 260
#define L_AS 261
#define L_JOIN 262
#define L_ON 263
#define L_ORDER 264
#define L_BY 265
#define L_DISTINCT 266
#define L_BETWEEN 267
#define L_IN 268
#define L_GROUP 269
#define L_INSERT 270
#define L_INTO 271
#define L_VALUES 272
#define L_UPDATE 273
#define L_SET 274
#define L_DOT 275
#define L_STAR 276
#define L_COMMA 277
#define L_NULL 278
#define L_LBRACKET 279
#define L_RBRACKET 280
#define L_IDENT 281
#define L_EQ 282
#define L_IS 283
#define L_LIKE 284
#define L_NOT 285
#define L_AND 286
#define L_OR 287
#define L_MINUS 288
#define L_PLUS 289
#define L_TIMES 290
#define L_DIV 291
#define L_STRING 292




#ifndef YYSTYPE
#line 17 "parser.y"
typedef union {
void *v;
char *str;
int i;
GList *list;
sql_field *f;
sql_field_item *fi;
sql_table *t;
sql_condition *c;
sql_where *w;
} yystype;
/* Line 1281 of /usr/share/bison/yacc.c.  */
#line 126 "parser.h"
# define YYSTYPE yystype
#endif

extern YYSTYPE sqllval;


#endif /* not BISON_PARSER_H */

==> libgda-0.91.0.tar.bz2: libgda-0.91.0/libsql/parser.h <==
/* A Bison parser, made by GNU Bison 1.875a.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     L_SELECT = 258,
     L_FROM = 259,
     L_WHERE = 260,
     L_AS = 261,
     L_JOIN = 262,
     L_ON = 263,
     L_ORDER = 264,
     L_BY = 265,
     L_DISTINCT = 266,
     L_BETWEEN = 267,
     L_IN = 268,
     L_GROUP = 269,
     L_INSERT = 270,
     L_INTO = 271,
     L_VALUES = 272,
     L_UPDATE = 273,
     L_SET = 274,
     L_DOT = 275,
     L_STAR = 276,
     L_COMMA = 277,
     L_NULL = 278,
     L_LBRACKET = 279,
     L_RBRACKET = 280,
     L_IDENT = 281,
     L_EQ = 282,
     L_IS = 283,
     L_LIKE = 284,
     L_NOT = 285,
     L_AND = 286,
     L_OR = 287,
     L_MINUS = 288,
     L_PLUS = 289,
     L_TIMES = 290,
     L_DIV = 291,
     L_STRING = 292,
     L_DELETE = 293
   };
#endif
#define L_SELECT 258
#define L_FROM 259
#define L_WHERE 260
#define L_AS 261
#define L_JOIN 262
#define L_ON 263
#define L_ORDER 264
#define L_BY 265
#define L_DISTINCT 266
#define L_BETWEEN 267
#define L_IN 268
#define L_GROUP 269
#define L_INSERT 270
#define L_INTO 271
#define L_VALUES 272
#define L_UPDATE 273
#define L_SET 274
#define L_DOT 275
#define L_STAR 276
#define L_COMMA 277
#define L_NULL 278
#define L_LBRACKET 279
#define L_RBRACKET 280
#define L_IDENT 281
#define L_EQ 282
#define L_IS 283
#define L_LIKE 284
#define L_NOT 285
#define L_AND 286
#define L_OR 287
#define L_MINUS 288
#define L_PLUS 289
#define L_TIMES 290
#define L_DIV 291
#define L_STRING 292
#define L_DELETE 293




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 17 "parser.y"
typedef union YYSTYPE {
void *v;
char *str;
int i;
GList *list;
sql_field *f;
sql_field_item *fi;
sql_table *t;
sql_condition *c;
sql_where *w;
} YYSTYPE;
/* Line 1240 of yacc.c.  */
#line 125 "parser.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE sqllval;
